import request from '@/utils/request'



// 批量通过内容
export function getIndexInfo() {
  return request({
    url: '/hj/basics/getIndexInfo',
    method: 'get'
  })
}




// 批量通过内容
export function handleUpDateOKShops(shopsId,data) {
  return request({
    url: '/hj/info/okshops/' + shopsId,
    method: 'post',
    data: data
  })
}

// 查询店铺信息列表
export function listInfo(query) {
  return request({
    url: '/hj/info/list',
    method: 'get',
    params: query
  })
}

// 查询店铺信息详细
export function getInfo(shopsId) {
  return request({
    url: '/hj/info/' + shopsId,
    method: 'get'
  })
}

// 新增店铺信息
export function addInfo(data) {
  return request({
    url: '/hj/info',
    method: 'post',
    data: data
  })
}

// 修改店铺信息
export function updateInfo(data) {
  return request({
    url: '/hj/info',
    method: 'put',
    data: data
  })
}

// 删除店铺信息
export function delInfo(shopsId) {
  return request({
    url: '/hj/info/' + shopsId,
    method: 'delete'
  })
}

// 导出店铺信息
export function exportInfo(query) {
  return request({
    url: '/hj/info/export',
    method: 'get',
    params: query
  })
}
